@@ -670,3 +670,358 @@ double meanLogical(Rcpp::LogicalVector x) { return(Rcpp::mean(x)); }
 // [[Rcpp::export]]
 Rcomplex meanComplex(Rcpp::ComplexVector x) { return(Rcpp::mean(x)); }
 
+
+// 30 Oct 2015: cumprod, cummin, cummax
+
+// [[Rcpp::export]]
+NumericVector runit_cumprod_nv(NumericVector xx){
+    NumericVector res = cumprod(xx) ;
+    return res ;
+}
+
+// [[Rcpp::export]]
+IntegerVector runit_cumprod_iv(IntegerVector xx){
+    IntegerVector res = cumprod(xx) ;
+    return res ;
+}
+
+// [[Rcpp::export]]
+ComplexVector runit_cumprod_cv(ComplexVector xx){
+    ComplexVector res = cumprod(xx) ;
+    return res ;
+}
+
+// [[Rcpp::export]]
+NumericVector runit_cummin_nv(NumericVector xx){
+    NumericVector res = cummin(xx) ;
+    return res ;
+}
+
+// [[Rcpp::export]]
+IntegerVector runit_cummin_iv(IntegerVector xx){
+    IntegerVector res = cummin(xx) ;
+    return res ;
+}
+
+// [[Rcpp::export]]
+NumericVector runit_cummax_nv(NumericVector xx){
+    NumericVector res = cummax(xx) ;
+    return res ;
+}
+
+// [[Rcpp::export]]
+IntegerVector runit_cummax_iv(IntegerVector xx){
+    IntegerVector res = cummax(xx) ;
+    return res ;
+}
+
+
+// 18 January 2016: median 
+
+// [[Rcpp::export]]
+double median_dbl(Rcpp::NumericVector x, bool na_rm = false) {
+    return Rcpp::median(x, na_rm);
+}
+
+// [[Rcpp::export]]
+double median_int(Rcpp::IntegerVector x, bool na_rm = false) {
+    return Rcpp::median(x, na_rm);
+}
+
+// [[Rcpp::export]]
+Rcomplex median_cx(Rcpp::ComplexVector x, bool na_rm = false) {
+    return Rcpp::median(x, na_rm);
+}
+
+// [[Rcpp::export]]
+Rcpp::String median_ch(Rcpp::CharacterVector x, bool na_rm = false) {
+    return Rcpp::median(x, na_rm);
+}
+
+
+// 12 March 2016: cbind
+// A. Numeric*
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix n_cbind_mm(Rcpp::NumericMatrix m1, Rcpp::NumericMatrix m2) {
+    return Rcpp::cbind(m1, m2);
+}
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix n_cbind_mv(Rcpp::NumericMatrix m1, Rcpp::NumericVector v1) {
+    return Rcpp::cbind(m1, v1);
+}
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix n_cbind_ms(Rcpp::NumericMatrix m1, double s1) {
+    return Rcpp::cbind(m1, s1);
+}
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix n_cbind_vv(Rcpp::NumericVector v1, Rcpp::NumericVector v2) {
+    return Rcpp::cbind(v1, v2);
+}
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix n_cbind_vm(Rcpp::NumericVector v1, Rcpp::NumericMatrix m1) {
+    return Rcpp::cbind(v1, m1);
+}
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix n_cbind_vs(Rcpp::NumericVector v1, double s1) {
+    return Rcpp::cbind(v1, s1);
+}
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix n_cbind_sm(double s1, Rcpp::NumericMatrix m1) {
+    return Rcpp::cbind(s1, m1);
+}
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix n_cbind_sv(double s1, Rcpp::NumericVector v1) {
+    return Rcpp::cbind(s1, v1);
+}
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix n_cbind_ss(double s1, double s2) {
+    return Rcpp::cbind(s1, s2);
+}
+
+// [[Rcpp::export]]
+Rcpp::NumericMatrix 
+n_cbind9(Rcpp::NumericMatrix m1, Rcpp::NumericVector v1, double s1,
+         Rcpp::NumericMatrix m2, Rcpp::NumericVector v2, double s2,
+         Rcpp::NumericMatrix m3, Rcpp::NumericVector v3, double s3) {
+    return Rcpp::cbind(m1, v1, s1, m2, v2, s2, m3, v3, s3);
+}
+
+
+// B. Integer*
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind_mm(Rcpp::IntegerMatrix m1, Rcpp::IntegerMatrix m2) {
+    return Rcpp::cbind(m1, m2);
+}
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind_mv(Rcpp::IntegerMatrix m1, Rcpp::IntegerVector v1) {
+    return Rcpp::cbind(m1, v1);
+}
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind_ms(Rcpp::IntegerMatrix m1, int s1) {
+    return Rcpp::cbind(m1, s1);
+}
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind_vv(Rcpp::IntegerVector v1, Rcpp::IntegerVector v2) {
+    return Rcpp::cbind(v1, v2);
+}
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind_vm(Rcpp::IntegerVector v1, Rcpp::IntegerMatrix m1) {
+    return Rcpp::cbind(v1, m1);
+}
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind_vs(Rcpp::IntegerVector v1, int s1) {
+    return Rcpp::cbind(v1, s1);
+}
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind_sm(int s1, Rcpp::IntegerMatrix m1) {
+    return Rcpp::cbind(s1, m1);
+}
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind_sv(int s1, Rcpp::IntegerVector v1) {
+    return Rcpp::cbind(s1, v1);
+}
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind_ss(int s1, int s2) {
+    return Rcpp::cbind(s1, s2);
+}
+
+// [[Rcpp::export]]
+Rcpp::IntegerMatrix 
+i_cbind9(Rcpp::IntegerMatrix m1, Rcpp::IntegerVector v1, int s1,
+         Rcpp::IntegerMatrix m2, Rcpp::IntegerVector v2, int s2,
+         Rcpp::IntegerMatrix m3, Rcpp::IntegerVector v3, int s3) {
+    return Rcpp::cbind(m1, v1, s1, m2, v2, s2, m3, v3, s3);
+}
+
+
+// C. Complex*
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind_mm(Rcpp::ComplexMatrix m1, Rcpp::ComplexMatrix m2) {
+    return Rcpp::cbind(m1, m2);
+}
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind_mv(Rcpp::ComplexMatrix m1, Rcpp::ComplexVector v1) {
+    return Rcpp::cbind(m1, v1);
+}
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind_ms(Rcpp::ComplexMatrix m1, Rcomplex s1) {
+    return Rcpp::cbind(m1, s1);
+}
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind_vv(Rcpp::ComplexVector v1, Rcpp::ComplexVector v2) {
+    return Rcpp::cbind(v1, v2);
+}
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind_vm(Rcpp::ComplexVector v1, Rcpp::ComplexMatrix m1) {
+    return Rcpp::cbind(v1, m1);
+}
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind_vs(Rcpp::ComplexVector v1, Rcomplex s1) {
+    return Rcpp::cbind(v1, s1);
+}
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind_sm(Rcomplex s1, Rcpp::ComplexMatrix m1) {
+    return Rcpp::cbind(s1, m1);
+}
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind_sv(Rcomplex s1, Rcpp::ComplexVector v1) {
+    return Rcpp::cbind(s1, v1);
+}
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind_ss(Rcomplex s1, Rcomplex s2) {
+    return Rcpp::cbind(s1, s2);
+}
+
+// [[Rcpp::export]]
+Rcpp::ComplexMatrix 
+cx_cbind9(Rcpp::ComplexMatrix m1, Rcpp::ComplexVector v1, Rcomplex s1,
+         Rcpp::ComplexMatrix m2, Rcpp::ComplexVector v2, Rcomplex s2,
+         Rcpp::ComplexMatrix m3, Rcpp::ComplexVector v3, Rcomplex s3) {
+    return Rcpp::cbind(m1, v1, s1, m2, v2, s2, m3, v3, s3);
+}
+
+
+// D. Logical*
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind_mm(Rcpp::LogicalMatrix m1, Rcpp::LogicalMatrix m2) {
+    return Rcpp::cbind(m1, m2);
+}
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind_mv(Rcpp::LogicalMatrix m1, Rcpp::LogicalVector v1) {
+    return Rcpp::cbind(m1, v1);
+}
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind_ms(Rcpp::LogicalMatrix m1, bool s1) {
+    return Rcpp::cbind(m1, s1);
+}
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind_vv(Rcpp::LogicalVector v1, Rcpp::LogicalVector v2) {
+    return Rcpp::cbind(v1, v2);
+}
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind_vm(Rcpp::LogicalVector v1, Rcpp::LogicalMatrix m1) {
+    return Rcpp::cbind(v1, m1);
+}
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind_vs(Rcpp::LogicalVector v1, bool s1) {
+    return Rcpp::cbind(v1, s1);
+}
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind_sm(bool s1, Rcpp::LogicalMatrix m1) {
+    return Rcpp::cbind(s1, m1);
+}
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind_sv(bool s1, Rcpp::LogicalVector v1) {
+    return Rcpp::cbind(s1, v1);
+}
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind_ss(bool s1, bool s2) {
+    return Rcpp::cbind(s1, s2);
+}
+
+// [[Rcpp::export]]
+Rcpp::LogicalMatrix 
+l_cbind9(Rcpp::LogicalMatrix m1, Rcpp::LogicalVector v1, bool s1,
+         Rcpp::LogicalMatrix m2, Rcpp::LogicalVector v2, bool s2,
+         Rcpp::LogicalMatrix m3, Rcpp::LogicalVector v3, bool s3) {
+    return Rcpp::cbind(m1, v1, s1, m2, v2, s2, m3, v3, s3);
+}
+
+
+// E. Character*
+
+// [[Rcpp::export]]
+Rcpp::CharacterMatrix 
+c_cbind_mm(Rcpp::CharacterMatrix m1, Rcpp::CharacterMatrix m2) {
+    return Rcpp::cbind(m1, m2);
+}
+
+// [[Rcpp::export]]
+Rcpp::CharacterMatrix 
+c_cbind_mv(Rcpp::CharacterMatrix m1, Rcpp::CharacterVector v1) {
+    return Rcpp::cbind(m1, v1);
+}
+
+// [[Rcpp::export]]
+Rcpp::CharacterMatrix 
+c_cbind_vv(Rcpp::CharacterVector v1, Rcpp::CharacterVector v2) {
+    return Rcpp::cbind(v1, v2);
+}
+
+// [[Rcpp::export]]
+Rcpp::CharacterMatrix 
+c_cbind_vm(Rcpp::CharacterVector v1, Rcpp::CharacterMatrix m1) {
+    return Rcpp::cbind(v1, m1);
+}
+
+// [[Rcpp::export]]
+Rcpp::CharacterMatrix 
+c_cbind6(Rcpp::CharacterMatrix m1, Rcpp::CharacterVector v1,
+         Rcpp::CharacterMatrix m2, Rcpp::CharacterVector v2,
+         Rcpp::CharacterMatrix m3, Rcpp::CharacterVector v3) {
+    return Rcpp::cbind(m1, v1, m2, v2, m3, v3);
+}
+
